@@ -14,8 +14,9 @@
 #
 # \arguments{
 #  \item{ds, ds1, ds2}{@see "GenericDataFileSet":s.}
-#  \item{IDXS}{A (named) @list, where each element contains a @vector data set indices,
-#    or an @integer @vector of individual elements.}
+#  \item{IDXS}{A (named) @list, where each element contains a @vector data
+#    set indices, or an @integer @vector of individual elements.
+#    If @NULL, then ... with names as of the data set.}
 #  \item{DROP}{If @FALSE, the first argument passed to \code{FUN} is always a @list of files.
 #    If @TRUE, an single-index element is passed to \code{FUN} as a file instead of
 #    as a @list containing a single file.}
@@ -33,7 +34,7 @@
 # }
 #
 # \value{
-#   Returns a named @list.
+#   Returns a named @list where the names are those of argument \code{IDXS}.
 # }
 #
 # \examples{\dontrun{
@@ -76,13 +77,13 @@ setMethodS3("dsApply", "GenericDataFileSet", function(ds, IDXS=NULL, DROP=is.nul
   # Argument 'IDXS':
   if (is.null(IDXS)) {
     IDXS <- seq_along(ds);
-    names(IDXS) <- getNames(ds);
+    names(IDXS) <- getFullNames(ds);
     IDXS <- as.list(IDXS);
   } else if (is.numeric(IDXS)) {
     max <- length(ds);
     IDXS <- Arguments$getIndices(IDXS, max=max);
     if (is.null(names(IDXS))) {
-      names(IDXS) <- getNames(ds);
+      names(IDXS) <- getFullNames(ds);
       IDXS <- as.list(IDXS);
     }
   } else if (is.list(IDXS)) {
@@ -403,7 +404,7 @@ setMethodS3("dsApplyInPairs", "GenericDataFileSet", function(ds1, ds2, ...) {
   dsP <- c(ds1, ds2)
   idxs <- matrix(seq_along(dsP), nrow=2L, byrow=TRUE)
   IDXS <- as.list(as.data.frame(idxs))
-  names <- getNames(dsP)
+  names <- getFullNames(dsP)
   names(IDXS) <- sapply(IDXS, FUN=function(idxs) {
     sprintf("Pair (%s,%s)", names[idxs[1]], names[idxs[2]])
   })
