@@ -1,18 +1,17 @@
-# Allows conflicts. For more information, see library() and
-# conflicts() in [R] base.
-.conflicts.OK <- TRUE
-
-
-## .First.lib <- function(libname, pkgname) {
-.onAttach <- function(libname, pkgname) {
+.onLoad <- function(libname, pkgname) {
+  ns <- getNamespace(pkgname);
   pkg <- Package(pkgname);
-  assign(pkgname, pkg, pos=getPosition(pkg));
+  assign(pkgname, pkg, envir=ns);
+}
+
+.onAttach <- function(libname, pkgname) {
+  pkg <- get(pkgname, envir=getNamespace(pkgname));
   startupMessage(pkg);
 }
 
 
 ############################################################################
-# HISTORY: 
+# HISTORY:
 # 2011-07-24
 # o Added a namespace to the package.
 ############################################################################
