@@ -13,11 +13,15 @@ ds <- GenericDataFileSet$byPath(path)
 print(ds)
 
 bys <- c("lexicographic", "filesize")
-if (require("gtools")) by <- c(by, "mixedsort")
+if (require("gtools")) {
+  bys <- c(bys, "mixeddecimal")
+  if (packageVersion("gtools") > "3.5.0") bys <- c(bys, "mixedroman")
+}
 for (by in bys) {
   for (decreasing in c(FALSE, TRUE)) {
     dsS  <- sortBy(ds, by=by, decreasing=FALSE)
-    print(as.list(dsS))
+    cat(sprintf("\nSort by '%s' (decreasing=%s):\n", by, decreasing))
+    cat(sQuote(names(dsS)), sep="\n")
   }
 }
 
